@@ -1,8 +1,8 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "mozc" "2.32.5994.102"
+(define-package "mozc" "3.33.6089"
   "Minor mode to input Japanese with Mozc."
   '((emacs "24.3"))
   :url "https://github.com/google/mozc"
-  :commit "d9c3f195582de6b0baa07ecb81a04e8902acf9af"
-  :revdesc "2.32.5994.102-0-gd9c3f195582d"
+  :commit "8f92cd985cba2fd009545963698f4df7424bec56"
+  :revdesc "3.33.6089-0-g8f92cd985cba"
   :keywords '("mule" "multilingual" "input method"))
